==> DhcpAdmin-1.0.tar.gz: DhcpAdmin/lib/libserverlist.pl <==
#
# dhcpadmin
#
# Copyright (C) 2008 DesigNET, INC.
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
#

##########################################################
#
# Хꥹȥ饤֥
#
# $RCSfile: libserverlist.pl,v $
# $Revision: 1.5 $
# $Date: 2008/12/22 03:09:11 $
#
##########################################################

use strict;

my $USERURL = "userlist.cgi";
my $DHCPURL = "top.cgi";

#
# Хꥹɽhtml
#
# 
#       arg0    ɽhtml(Ϥ)
#       arg1    serverid
#       arg2    å(0: DHCP, 1:桼)
#       arg3    顼å
#
# ֤
#       0       
#       -1      顼
#

sub make_serverlisthtml
{
    my ($listhtml, $serverid, $switch, $rip, $errmsg) = @_;
    my %dummylistdata;
    my $dummy;          # ߡѿ(Ѥʤ)
    my @serverlist;
    my $servername;
    my $url;
    my $dist;
    my $line;
    my $array;
    my $i;
    my $key;
    my %list;

    # URL(桼ORDHCP)
    if ($switch == 0) {
	$dist = $DHCPURL;
    } else {
	$dist = $USERURL;
    }

    # Сꥹɤ߹
    if (get_serverlist(\%dummylistdata, \$dummy, \@serverlist, $errmsg) != 0) {
        $$listhtml =<<EOD;
  <tr>
    <td class="message">$$errmsg[$main::L_DISP]</td>
  </tr>
EOD
        return -1;
    }
   
    # 
    $array = @serverlist;

    for ($i = 0; $i < $array; $i++) {
        %list = %{$serverlist[$i]};
        foreach $servername (keys %list) {
            if ($serverid eq $servername) {
                $$listhtml .=<<EOD;
<tr><td>$servername</td></tr>
EOD
            } else {
                $$listhtml .=<<EOD;
  <tr>
    <td>
      <a href=/$servername/$dist?rip=$rip onClick="LinkPost('$servername')" target="right"> $servername </a>
    </td>
  </tr>
EOD
            }
            $$listhtml .=<<EOD;
EOD

        }
    }

    $$listhtml .=<<EOD;
<input type="hidden" name="serverid" value="">
EOD

    return 0;

}

1;

==> DhcpAdmin-1.01.tar.gz: DhcpAdmin/lib/libserverlist.pl <==
#
# dhcpadmin
#
# Copyright (C) 2008 DesigNET, INC.
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
#

##########################################################
#
# Хꥹȥ饤֥
#
# $RCSfile: libserverlist.pl,v $
# $Revision: 1.6 $
# $Date: 2012/12/19 06:57:50 $
#
##########################################################

use strict;

my $USERURL = "userlist.cgi";
my $DHCPURL = "top.cgi";

#
# Хꥹɽhtml
#
# 
#       arg0    ɽhtml(Ϥ)
#       arg1    serverid
#       arg2    å(0: DHCP, 1:桼)
#       arg3    顼å
#
# ֤
#       0       
#       -1      顼
#

sub make_serverlisthtml
{
    my ($listhtml, $serverid, $switch, $rip, $errmsg) = @_;
    my %dummylistdata;
    my $dummy;          # ߡѿ(Ѥʤ)
    my @serverlist;
    my $servername;
    my $url;
    my $dist;
    my $line;
    my $array;
    my $i;
    my $key;
    my %list;

    # URL(桼ORDHCP)
    if ($switch == 0) {
	$dist = $DHCPURL;
    } else {
	$dist = $USERURL;
    }

    # Сꥹɤ߹
    if (get_serverlist(\%dummylistdata, \$dummy, \@serverlist, $errmsg) != 0) {
        $$listhtml =<<EOD;
  <tr>
#    <td class="message">$$errmsg[$main::L_DISP]</td>
  </tr>
EOD
        return -1;
    }
   
    # 
    $array = @serverlist;

    for ($i = 0; $i < $array; $i++) {
        %list = %{$serverlist[$i]};
        foreach $servername (keys %list) {
            if ($serverid eq $servername) {
                $$listhtml .=<<EOD;
<tr><td>$servername</td></tr>
EOD
            } else {
                $$listhtml .=<<EOD;
  <tr>
    <td>
      <a href=/$servername/$dist?rip=$rip onClick="LinkPost('$servername')" target="right"> $servername </a>
    </td>
  </tr>
EOD
            }
            $$listhtml .=<<EOD;
EOD

        }
    }

    $$listhtml .=<<EOD;
<input type="hidden" name="serverid" value="">
EOD

    return 0;

}

1;
